Describe the issue briefly here.

##### Environment Versions

1. OS Type
1. Python version: `$ python -V`
1. pip version:  `$ pip --version`
1. pip-tools version: `$ pip-compile --version`

##### Steps to replicate

1. ...
2. ...
3. ...

##### Expected result

...

##### Actual result

...
